{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "![Callysto.ca Banner](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-top.jpg?raw=true)\n",
    "\n",
    "<a href=\"https://hub.callysto.ca/jupyter/hub/user-redirect/git-pull?repo=https%3A%2F%2Fgithub.com%2Fcallysto%2Fcurriculum-notebooks&branch=master&subPath=Science/ClassifyingChemicalReactions/classifying-chemical-reactions.ipynb&depth=1\" target=\"_parent\"><img src=\"https://raw.githubusercontent.com/callysto/curriculum-notebooks/master/open-in-callysto-button.svg?sanitize=true\" width=\"123\" height=\"24\" alt=\"Open in Callysto\"/></a>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<script>\n",
       "  function code_toggle() {\n",
       "    if (code_shown){\n",
       "      $('div.input').hide('500');\n",
       "      $('#toggleButton').val('Show Code')\n",
       "    } else {\n",
       "      $('div.input').show('500');\n",
       "      $('#toggleButton').val('Hide Code')\n",
       "    }\n",
       "    code_shown = !code_shown\n",
       "  }\n",
       "\n",
       "  $( document ).ready(function(){\n",
       "    code_shown=false;\n",
       "    $('div.input').hide()\n",
       "  });\n",
       "</script>\n",
       "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>\n"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%%html\n",
    "\n",
    "<script>\n",
    "  function code_toggle() {\n",
    "    if (code_shown){\n",
    "      $('div.input').hide('500');\n",
    "      $('#toggleButton').val('Show Code')\n",
    "    } else {\n",
    "      $('div.input').show('500');\n",
    "      $('#toggleButton').val('Hide Code')\n",
    "    }\n",
    "    code_shown = !code_shown\n",
    "  }\n",
    "\n",
    "  $( document ).ready(function(){\n",
    "    code_shown=false;\n",
    "    $('div.input').hide()\n",
    "  });\n",
    "</script>\n",
    "<form action=\"javascript:code_toggle()\"><input type=\"submit\" id=\"toggleButton\" value=\"Show Code\"></form>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "(Click **Cell** > **Run All** before proceeding.) "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [],
   "source": [
    "%matplotlib inline\n",
    "from helper import *"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Classifying Chemical Equations"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Introduction\n",
    "\n",
    "A **chemical equation** is used to describe the  process that involves the rearrangement of the atoms in the molecular or ionic structure of a substance or material. All chemical reactions involve the formation or destruction of chemical bonds wherein reactants are transformed into products. Chemical reactions take place all around us and within us. Many of these chemical reactions share similar characteristics to one another, which allow them to be grouped and classified in a number of different ways. One common classification scheme organizes chemical reactions into four types: \n",
    "\n",
    "* <a href=\"#combination\">Combination reactions</a> \n",
    "* <a href=\"#decomposition\">Decomposition reactions</a> \n",
    "* <a href=\"#single\">Single replacement reactions</a>\n",
    "* <a href=\"#double\">Double replacement reactions</a>\n",
    "\n",
    "## <a id=\"combination\"> #1 Combination Reaction</a>\n",
    "\n",
    "A **combination reaction** (also called a *synthesis reaction*) describes the process in which two or more reactants combine to form a new singular product. The general form for a combination reaction is given below: \n",
    "\n",
    "<img src=\"images/combination_reaction.svg\" width=\"55%\"/>\n",
    "\n",
    "The reactant side may contain two or more elements or compounds, but the product side will always contain only one compound. This is the key characteristic of a combination reaction. Combination reactions may include reactions between two or more elements:\n",
    "\n",
    "2H<sub>2</sub> + O<sub>2</sub> &rarr; 2H<sub>2</sub>O\n",
    "\n",
    "Between elements and compounds:\n",
    "\n",
    "O<sub>2</sub> + 2CO &rarr; 2CO<sub>2</sub>\n",
    "\n",
    "Or between compounds:\n",
    "\n",
    "CaO + CO<sub>2</sub> &rarr; CaCO<sub>3</sub>\n",
    "\n",
    "The new bonds formed in the product are often lower in energy than the bonds in the reactants. When this occurs, energy is released, often in the form of heat. As a consequence, combination reactions are usually exothermic."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Practice Problems"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Select 'True' or 'False' for each of the follow statements.* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "scrolled": true,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "71ad3cb1651b48c38505ec15e5d23dd2",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "541fc4a6c4b14a8b9ccd9a8d5f0376da",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "2c5e4343cc4b4546b37f77ec60fad872",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "3652571ed4054853b5fbf9830ce4e238",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "randomize_1 = random.randint(1, 2)\n",
    "if randomize_1 == 1:\n",
    "    option_1 = \"Combination reactions are often exothermic.\"; bool_1 = True\n",
    "elif randomize_1 == 2:\n",
    "    option_1 = \"Combination reactions are often endothermic.\"; bool_1 = False\n",
    "\n",
    "randomize_1 = random.randint(1, 4)\n",
    "if randomize_1 == 1:\n",
    "    option_2 = \"Combination reactions always have two or more reactants, but only one product.\"; bool_2 = True\n",
    "elif randomize_1 == 2:\n",
    "    option_2 = \"Combination reactions always have two or more reactants, but only one product.\"; bool_2 = True    \n",
    "elif randomize_1 == 3:\n",
    "    option_2 = \"Combination reactions always have two or more reactants, and two or more products.\"; bool_2 = False\n",
    "elif randomize_1 == 4:\n",
    "    option_2 = \"Combination reactions always have one reactant, and one product.\"; bool_2 = False\n",
    "\n",
    "randomize_1 = random.randint(1, 6)\n",
    "if randomize_1 == 1:\n",
    "    option_3 = \"The general form of a combination reaction is: A + B &rarr; AB.\"; bool_3 = True\n",
    "elif randomize_1 == 2:\n",
    "    option_3 = \"The general form of a combination reaction is: A + B &rarr; AB.\"; bool_3 = True\n",
    "elif randomize_1 == 3:\n",
    "    option_3 = \"The general form of a combination reaction is: A + B &rarr; AB.\"; bool_3 = True\n",
    "elif randomize_1 == 4:\n",
    "    option_3 = \"The general form of a combination reaction is: AB &rarr; A + B.\"; bool_3 = False\n",
    "elif randomize_1 == 5:\n",
    "    option_3 = \"The general form of a combination reaction is: AB + X &rarr; XB + A.\"; bool_3 = False\n",
    "elif randomize_1 == 6:\n",
    "    option_3 = \"The general form of a combination reaction is: AB + XY &rarr; XB + AY.\"; bool_3 = False\n",
    "\n",
    "randomize_1 = random.randint(1, 2)\n",
    "if randomize_1 == 1:\n",
    "    option_4 = \"The product generated from a combination reaction is always a compound.\"; bool_4 = True\n",
    "elif randomize_1 == 2:\n",
    "    option_4 = \"The product generated from a combination reaction is always an element.\"; bool_4 = False    \n",
    "\n",
    "true_false(option_1, bool_1, option_2, bool_2, option_3, bool_3, option_4, bool_4, \"True\", \"False\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Which of the follow chemical reactions is a combination reaction?* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "scrolled": false,
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "b9639daa7917483b8aa7702d4b872815",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> CH<sub>4</sub> + 2O<sub>2</sub> &rarr; CO<sub>2</sub> + 2H<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "26589e936d9344d08aa3a15290a25294",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> NaCl + AgNO<sub>3</sub> &rarr; AgCl + NaNO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a43e838b9b944c24bc29154e1b299632",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2NaCl + F<sub>2</sub> &rarr; 2NaF + Cl<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "03057e49c49b40e9b1418abc93eaab06",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> Ba + F<sub>2</sub> &rarr; BaF<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d837bb4772db4923b37ef8dc9b5e8ed3",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Ba + F<sub>2</sub> &rarr; BaF<sub>2</sub>\" \n",
    "option_2 = \"NaCl + AgNO<sub>3</sub> &rarr; AgCl + NaNO<sub>3</sub>\"\n",
    "option_3 = \"CH<sub>4</sub> + 2O<sub>2</sub> &rarr; CO<sub>2</sub> + 2H<sub>2</sub>O\"\n",
    "option_4 = \"2NaCl + F<sub>2</sub> &rarr; 2NaF + Cl<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "76ebe886964c45539d9ae8a0576fa14b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> 2HBr + Cl<sub>2</sub> &rarr; 2HCl + Br<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "6608c651cdf54208a08f2d5a3f39d99b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> Fe + S &rarr; FeS')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f01ec1dcd3454274af07aff1c81f1691",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> C<sub>2</sub>H<sub>5</sub>OH + 3O<sub>2</sub> &rarr; 2CO<sub>2</sub> + 3H<sub>2</su…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f556e2da49e541a48f291943880ae146",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> Zn + 2HCl &rarr; ZnCl<sub>2</sub> + H<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c59f8ae5db50451fa1d77e2837e63d93",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Fe + S &rarr; FeS\" \n",
    "option_2 = \"2HBr + Cl<sub>2</sub> &rarr; 2HCl + Br<sub>2</sub>\"\n",
    "option_3 = \"C<sub>2</sub>H<sub>5</sub>OH + 3O<sub>2</sub> &rarr; 2CO<sub>2</sub> + 3H<sub>2</sub>O\"\n",
    "option_4 = \"Zn + 2HCl &rarr; ZnCl<sub>2</sub> + H<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "7bb0be826e484ca9bea569ec02813f16",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> NaNO<sub>3</sub> + KCl &rarr; KNO<sub>3</sub> + NaCl')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "be50ef1b9dbf4d7f865acd7ea856219b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> Na<sub>2</sub>CO<sub>3</sub> &rarr; Na<sub>2</sub>O + CO<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d550918919df496dad40cbb77523edca",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 4NH<sub>3</sub> + 3O<sub>2</sub> &rarr; 2N<sub>2</sub> + 6H<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "402a4d3d19b14eba875bbd2aca4b423b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> MgO + CO<sub>2</sub> &rarr; MgCO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "e746b9185d8a4c5faebd1454089e429d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"MgO + CO<sub>2</sub> &rarr; MgCO<sub>3</sub>\" \n",
    "option_2 = \"Na<sub>2</sub>CO<sub>3</sub> &rarr; Na<sub>2</sub>O + CO<sub>2</sub>\"\n",
    "option_3 = \"4NH<sub>3</sub> + 3O<sub>2</sub> &rarr; 2N<sub>2</sub> + 6H<sub>2</sub>O\"\n",
    "option_4 = \"NaNO<sub>3</sub> + KCl &rarr; KNO<sub>3</sub> + NaCl\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "0debd32bcc654cbf9aa01d7ff1d8bf18",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> CaCO<sub>3</sub> &rarr; CaO + CO<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "0749ec01ab4e4905bbccdf7d40edb6a8",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2S + 3O<sub>2</sub> &rarr; 2SO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "3bedf67092994f95929b6dd03139022f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> KBr + AgNO<sub>3</sub> &rarr; KNO<sub>3</sub> + AgBr')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "ff78cddaaf344c209fd15c48424dc77a",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> C<sub>3</sub>H<sub>8</sub> + 5O<sub>2</sub> &rarr; 3CO<sub>2</sub> + 4H<sub>2</sub>…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a92affc724be4942ab82badfa9215c9e",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"2S + 3O<sub>2</sub> &rarr; 2SO<sub>3</sub>\" \n",
    "option_2 = \"CaCO<sub>3</sub> &rarr; CaO + CO<sub>2</sub>\"\n",
    "option_3 = \"C<sub>3</sub>H<sub>8</sub> + 5O<sub>2</sub> &rarr; 3CO<sub>2</sub> + 4H<sub>2</sub>O\"\n",
    "option_4 = \"KBr + AgNO<sub>3</sub> &rarr; KNO<sub>3</sub> + AgBr\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## <a id=\"decomposition\"> #2 Decomposition Reaction</a>\n",
    "\n",
    "A **decomposition reaction** describes the process in which a single reactant breaks down to form two or more products. The general form for a decomposition reaction is given below:\n",
    "\n",
    "<img src=\"images/decomposition_reaction.svg\" width=\"55%\"/>\n",
    "\n",
    "The reactant side will always contain a compound, but the product side may contain two or more elements or compounds. This is the key characteristic of a decomposition reaction. For example, the products may include two or more elements:\n",
    "\n",
    "2H<sub>2</sub>O &rarr; 2H<sub>2</sub> + O<sub>2</sub>\n",
    "\n",
    "Elements and compounds:\n",
    "\n",
    "2KClO<sub>3</sub> &rarr; 3O<sub>2</sub> + 2KCl\n",
    "\n",
    "Or two or more compounds:\n",
    "\n",
    "NH<sub>4</sub>Cl &rarr; NH<sub>3</sub> + HCl\n",
    "\n",
    "The new bonds formed in the products are often higher in energy than the bonds in the reactant. When this occurs, some energy, usually in the form of heat, is needed. As a consequence, decomposition reactions are usually endothermic."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Practice Problems"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Select 'True' or 'False' for each of the follow statements.* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "1d9aa19ef55041d997db088d9e0b0d9b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c32626d42105488182c9cb506586414c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f4b3960118a5461b9c3de7b42ff24b4b",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "755a53f3ca044bc7bd6a19dbaa0acd9e",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "randomize_2 = random.randint(1, 2)\n",
    "if randomize_2 == 1:\n",
    "    option_1 = \"Decomposition reactions are often endothermic.\"; bool_1 = True\n",
    "elif randomize_2 == 2:\n",
    "    option_1 = \"Decomposition reactions are often exothermic.\"; bool_1 = False\n",
    "\n",
    "randomize_2 = random.randint(1, 4)\n",
    "if randomize_2 == 1:\n",
    "    option_2 = \"Decomposition reactions always have one reactant, but two or more products.\"; bool_2 = True\n",
    "elif randomize_2 == 2:    \n",
    "    option_2 = \"Decomposition reactions always have one reactant, but two or more products.\"; bool_2 = True\n",
    "elif randomize_2 == 3:\n",
    "    option_2 = \"Decomposition reactions always have two or more reactants, and two or more products.\"; bool_2 = False\n",
    "elif randomize_2 == 4:\n",
    "    option_2 = \"Decomposition reactions always have one reactant, and one product.\"; bool_2 = False\n",
    "\n",
    "randomize_2 = random.randint(1, 6)\n",
    "if randomize_2 == 1:\n",
    "    option_3 = \"The general form of a decomposition reaction is: AB &rarr; A + B.\"; bool_3 = True\n",
    "elif randomize_2 == 2:\n",
    "    option_3 = \"The general form of a decomposition reaction is: AB &rarr; A + B.\"; bool_3 = True\n",
    "elif randomize_2 == 3:\n",
    "    option_3 = \"The general form of a decomposition reaction is: AB &rarr; A + B.\"; bool_3 = True\n",
    "elif randomize_2 == 4:\n",
    "    option_3 = \"The general form of a decomposition reaction is: A + B &rarr; AB.\"; bool_3 = False\n",
    "elif randomize_2 == 5:\n",
    "    option_3 = \"The general form of a decomposition reaction is: AB + X &rarr; XB + A.\"; bool_3 = False\n",
    "elif randomize_2 == 6:\n",
    "    option_3 = \"The general form of a decomposition reaction is: AB + XY &rarr; XB + AY.\"; bool_3 = False\n",
    "\n",
    "randomize_2 = random.randint(1, 2)\n",
    "if randomize_2 == 1:\n",
    "    option_4 = \"The reactant in a decomposition reaction is always a compound.\"; bool_4 = True\n",
    "elif randomize_2 == 2:\n",
    "    option_4 = \"The reactant in a decomposition reaction is always an element.\"; bool_4 = False    \n",
    "\n",
    "true_false(option_1, bool_1, option_2, bool_2, option_3, bool_3, option_4, bool_4, \"True\", \"False\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Which of the follow chemical reactions is a decomposition reaction?* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c26749f344d0487799b0f11cdeac783a",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> SeCl<sub>6</sub> + O<sub>2</sub> &rarr; SeO<sub>2</sub> + 3Cl<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a8126df30231450bb4ed83512c429f0f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> Ba + F<sub>2</sub> &rarr; BaF<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "0d8b5b9b7b9449b597cd91e53159fe2d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> Na<sub>2</sub>S + 2HCl &rarr; 2NaCl + H<sub>2</sub>S')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c889335d68fc421285ccad5b331005bd",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> 2Ni<sub>2</sub>O<sub>3</sub> &rarr; 4Ni + 3O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "66ee2c9537694369805cd73989b3d6ca",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"2Ni<sub>2</sub>O<sub>3</sub> &rarr; 4Ni + 3O<sub>2</sub>\" \n",
    "option_2 = \"Na<sub>2</sub>S + 2HCl &rarr; 2NaCl + H<sub>2</sub>S\"\n",
    "option_3 = \"SeCl<sub>6</sub> + O<sub>2</sub> &rarr; SeO<sub>2</sub> + 3Cl<sub>2</sub>\"\n",
    "option_4 = \"Ba + F<sub>2</sub> &rarr; BaF<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "bed6a1ec0e75458a8a7b9142c62c873d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> Fe + S &rarr; FeS')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "9f7704a1d57d494dadb74f0676d3edf1",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2NaOH + CaBr<sub>2</sub> &rarr; 2NaBr + Ca(OH)<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f5741c848f1142c1805aacb08200e589",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> Zn + 2HCl &rarr; H<sub>2</sub> + ZnCl<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c8c6e379964645fb86c9cd92acf71653",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> Al<sub>2</sub>O<sub>3</sub> &rarr; Al + O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "01e66399379a4502bb665a8335bcd7d7",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Al<sub>2</sub>O<sub>3</sub> &rarr; Al + O<sub>2</sub>\" \n",
    "option_2 = \"2NaOH + CaBr<sub>2</sub> &rarr; 2NaBr + Ca(OH)<sub>2</sub>\"\n",
    "option_3 = \"Fe + S &rarr; FeS\"\n",
    "option_4 = \"Zn + 2HCl &rarr; H<sub>2</sub> + ZnCl<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "87e9e969ca2d4755a594673ca26c6380",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> CH<sub>4</sub> + 2O<sub>2</sub> &rarr; CO<sub>2</sub> + 2H<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "73ed2b2769d742b68a05558d2f7f5dc8",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2NaCl + F<sub>2</sub> &rarr; 2NaF + Cl<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "2604dbec3d004cfcb23446bbd4bd9f48",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2NaClO<sub>3</sub> &rarr; 2NaCl + 3O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "5949b292460a48aa94bc1bda84f9132e",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> MgO + CO<sub>2</sub> &rarr; MgCO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c709e9d4eb0040b8a3b3105af7de93dc",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"2NaClO<sub>3</sub> &rarr; 2NaCl + 3O<sub>2</sub>\" \n",
    "option_2 = \"MgO + CO<sub>2</sub> &rarr; MgCO<sub>3</sub>\"\n",
    "option_3 = \"2NaCl + F<sub>2</sub> &rarr; 2NaF + Cl<sub>2</sub>\"\n",
    "option_4 = \"CH<sub>4</sub> + 2O<sub>2</sub> &rarr; CO<sub>2</sub> + 2H<sub>2</sub>O\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "44c2511b2e734a259aaa2737e653370d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> 2S + 3O<sub>2</sub> &rarr; 2SO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "97b678c346124170bdacdd714ad0f169",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> CaCO<sub>3</sub> &rarr; CaO + CO<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "8dc33a1a55354dbe98181c4c13a74acc",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2Al + 3Cu(NO<sub>3</sub>)<sub>2</sub> &rarr; 3Cu + 2Al(NO<sub>3</sub>)<sub>3</sub>'…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f70498d17fb44303897d46cb676da27d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> FeS + 2HCl &rarr; FeCl<sub>2</sub> + H<sub>2</sub>S')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "92a0f3a421564f67a06025dd64f9e0b1",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"CaCO<sub>3</sub> &rarr; CaO + CO<sub>2</sub>\" \n",
    "option_2 = \"2S + 3O<sub>2</sub> &rarr; 2SO<sub>3</sub>\"\n",
    "option_3 = \"2Al + 3Cu(NO<sub>3</sub>)<sub>2</sub> &rarr; 3Cu + 2Al(NO<sub>3</sub>)<sub>3</sub>\"\n",
    "option_4 = \"FeS + 2HCl &rarr; FeCl<sub>2</sub> + H<sub>2</sub>S\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## <a id=\"single\"> #3 Single Replacement Reaction</a>\n",
    "\n",
    "A **single replacement reaction** (also called a *single displacement reaction*) describes the process in which one element replaces another element in a compound. The general form for a single replacement reaction is given below:\n",
    "\n",
    "<img src=\"images/single_displacement_reaction.svg\" width=\"78%\"/>\n",
    "\n",
    "The reactant side always contains at least one pure element and one compound. Likewise, the product side always contains at least one pure element and one compound. Only positive ions (cations) can replace other positive ions, while only negative ions (anions) can replace other negative ions. In the general equation shown above, <b>X</b> must be positive because it replaces <b>A</b>. If <b>X</b> was negative, then it would replace <b>B</b>.\n",
    "\n",
    "Below is an example of cation replacement, in which the positive ion (Ni<sup>2+</sup>) is replaced by another positive ion (Zn<sup>2+</sup>):\n",
    "\n",
    "<span style=\"color:red\">Ni</span>Cl<sub>2</sub> + <span style=\"color:blue\">Zn</span> &rarr; <span style=\"color:blue\">Zn</span>Cl<sub>2</sub> + <span style=\"color:red\">Ni</span>\n",
    "\n",
    "Below is an example of anion replacement, in which the negative ion (Br<sup>-</sup>) is replaced by another negative ion (Cl<sup>-</sup>):\n",
    "\n",
    "2Na<span style=\"color:red\">Br</span> + <span style=\"color:blue\">Cl<sub>2</sub></span> &rarr; 2Na<span style=\"color:blue\">Cl</span> + <span style=\"color:red\">Br<sub>2</sub></span>\n",
    "\n",
    "Notice how the elements shown in <span style=\"color:blue\">blue</span> replace the elements shown in <span style=\"color:red\">red</span> in each of these examples."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Practice Problems"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Select 'True' or 'False' for each of the follow statements.* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a6567fab4de545a6a4823049b4217dbb",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "018ea9cbe8a546babe3954c8d9c42e69",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "52651a434d77478bac626023bb242e54",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "c9b7880dbe03434c96c256d07f963e8c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "randomize_3 = random.randint(1, 2)\n",
    "if randomize_3 == 1:\n",
    "    option_1 = \"Single replacement reactions are also called single displacement reactions.\"; bool_1 = True\n",
    "elif randomize_3 == 2:\n",
    "    option_1 = \"Single replacement reactions are also called synthesis reactions.\"; bool_1 = False\n",
    "\n",
    "randomize_3 = random.randint(1, 4)\n",
    "if randomize_3 == 1:\n",
    "    option_2 = \"The reactants used in a single replacement reaction always include one element and one compound.\"; bool_2 = True\n",
    "elif randomize_3 == 2:\n",
    "    option_2 = \"The reactants used in a single replacement reaction always include one element and one compound.\"; bool_2 = True\n",
    "elif randomize_3 == 3:\n",
    "    option_2 = \"The reactants used in a single replacement reaction always include two elements and no compounds.\"; bool_2 = False\n",
    "elif randomize_3 == 4:\n",
    "    option_2 = \"The reactants used in a single replacement reaction always include two compounds and no elements.\"; bool_2 = False\n",
    "    \n",
    "randomize_3 = random.randint(1, 6)\n",
    "if randomize_3 == 1:\n",
    "    option_3 = \"The general form of a single replacement reaction is: AB + X &rarr; XB + A.\"; bool_3 = True\n",
    "elif randomize_3 == 2:\n",
    "    option_3 = \"The general form of a single replacement reaction is: AB + X &rarr; XB + A.\"; bool_3 = True\n",
    "elif randomize_3 == 3:\n",
    "    option_3 = \"The general form of a single replacement reaction is: AB + Y &rarr; AY + B.\"; bool_3 = True\n",
    "elif randomize_3 == 4:\n",
    "    option_3 = \"The general form of a single replacement reaction is: AB &rarr; A + B.\"; bool_3 = False\n",
    "elif randomize_3 == 5:\n",
    "    option_3 = \"The general form of a single replacement reaction is: A + B &rarr; AB.\"; bool_3 = False\n",
    "elif randomize_3 == 6:\n",
    "    option_3 = \"The general form of a single replacement reaction is: AB + XY &rarr; XB + AY.\"; bool_3 = False\n",
    "\n",
    "randomize_3 = random.randint(1, 4)\n",
    "if randomize_3 == 1:\n",
    "    option_4 = \"The products generated from a single replacement reaction always include one element and one compound.\"; bool_4 = True\n",
    "elif randomize_3 == 2:\n",
    "    option_4 = \"The products generated from a single replacement reaction always include one element and one compound.\"; bool_4 = True\n",
    "elif randomize_3 == 3:\n",
    "    option_4 = \"The products generated from a single replacement reaction always include two elements and no compounds.\"; bool_4 = False    \n",
    "elif randomize_3 == 4:\n",
    "    option_4 = \"The products generated from a single replacement reaction always include two compounds and no elements.\"; bool_4 = False \n",
    "    \n",
    "true_false(option_1, bool_1, option_2, bool_2, option_3, bool_3, option_4, bool_4, \"True\", \"False\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Which of the follow chemical reactions is a single replacement reaction?* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "7e0f3f8e127641b2a4e65c38a74c9e20",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> 2Na + Cl<sub>2</sub> &rarr; 2NaCl')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "eca2433d687545a8979f0dbe44f5894f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2Ag<sub>2</sub>O &rarr; 4Ag + O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "3bc410d390f24786878d82bac3e399c8",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2Ag(NO<sub>3</sub>) + Cu &rarr; Cu(NO<sub>3</sub>)<sub>2</sub> + 2Ag')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "6d2b905447c64965a27c726e7cf5cbb9",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> 2MgI<sub>2</sub> + Mn(SO<sub>3</sub>)<sub>2</sub> &rarr; 2MgSO<sub>3</sub> + MnI<su…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "8a2a7936282f4a4e89d9044d27a97cf2",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"2Ag(NO<sub>3</sub>) + Cu &rarr; Cu(NO<sub>3</sub>)<sub>2</sub> + 2Ag\" \n",
    "option_2 = \"2Na + Cl<sub>2</sub> &rarr; 2NaCl\"\n",
    "option_3 = \"2Ag<sub>2</sub>O &rarr; 4Ag + O<sub>2</sub>\"\n",
    "option_4 = \"2MgI<sub>2</sub> + Mn(SO<sub>3</sub>)<sub>2</sub> &rarr; 2MgSO<sub>3</sub> + MnI<sub>4</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "2705bf09823243a7ae9902ea3f742945",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> 2NO<sub>2</sub> &rarr; 2O<sub>2</sub> + N<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "eafde34897fd48e1b9de89a2e5687c56",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2KI + Br<sub>2</sub> &rarr; 2KBr + I<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "11c1803f513e45e685b3ab80eecdae38",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2Ca + O<sub>2</sub> &rarr; 2CaO')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "13e5d3d23ba645059d2aa5d42b8723ba",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> Na<sub>3</sub>PO<sub>4</sub> + 3KOH &rarr; 3NaOH + K<sub>3</sub>PO<sub>4</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "7932909435564a018dd5e7f59a34f46f",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"2KI + Br<sub>2</sub> &rarr; 2KBr + I<sub>2</sub>\" \n",
    "option_2 = \"2Ca + O<sub>2</sub> &rarr; 2CaO\"\n",
    "option_3 = \"2NO<sub>2</sub> &rarr; 2O<sub>2</sub> + N<sub>2</sub>\"\n",
    "option_4 = \"Na<sub>3</sub>PO<sub>4</sub> + 3KOH &rarr; 3NaOH + K<sub>3</sub>PO<sub>4</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 16,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "e42cd958b635474baa4ced73f2be4e47",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> C<sub>3</sub>H<sub>6</sub>O + 4O<sub>2</sub> &rarr; 3CO<sub>2</sub> + 3H<sub>2</sub…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "1b262c36d5be4bbb92a81f8091049d60",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> Zn + H<sub>2</sub>SO<sub>4</sub> &rarr; ZnSO<sub>4</sub> + H<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "89c95e755ca34cc3b9697088492b4bb4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> Ca(OH)<sub>2</sub> &rarr; CaO + H<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f650dca5109745d3ab5d2a65f2884ba5",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> 2Li + S &rarr; Li<sub>2</sub>S')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "21421e60786d445cae45c5b34a3024a4",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Zn + H<sub>2</sub>SO<sub>4</sub> &rarr; ZnSO<sub>4</sub> + H<sub>2</sub>\" \n",
    "option_2 = \"2Li + S &rarr; Li<sub>2</sub>S\"\n",
    "option_3 = \"C<sub>3</sub>H<sub>6</sub>O + 4O<sub>2</sub> &rarr; 3CO<sub>2</sub> + 3H<sub>2</sub>O\"\n",
    "option_4 = \"Ca(OH)<sub>2</sub> &rarr; CaO + H<sub>2</sub>O\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 17,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "33647db389654a12aa128d1f47164efc",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> Cl<sub>2</sub> + CaI<sub>2</sub> &rarr; CaCl<sub>2</sub> + I<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "98a97b135dbf4c288ac1f455d3275e9d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 3H<sub>2</sub> + N<sub>2</sub> &rarr; 2NH<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "34efe62f463e45178eca20951dad3ed8",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2Hg<sub>2</sub>O &rarr; 4Hg + O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "38c6c8c8782246849fa19af3365c26cb",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> AgNO<sub>3</sub> + KI &rarr; AgI + KNO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "b6f6d90cbd924085bb1a231bc67df3d8",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Cl<sub>2</sub> + CaI<sub>2</sub> &rarr; CaCl<sub>2</sub> + I<sub>2</sub>\" \n",
    "option_2 = \"3H<sub>2</sub> + N<sub>2</sub> &rarr; 2NH<sub>3</sub>\"\n",
    "option_3 = \"2Hg<sub>2</sub>O &rarr; 4Hg + O<sub>2</sub>\"\n",
    "option_4 = \"AgNO<sub>3</sub> + KI &rarr; AgI + KNO<sub>3</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Reactivity Series\n",
    "\n",
    "The reactivity of a metal is determined by its tendency to donate electrons (a process known as **oxidation**). The reactivity of a halogen is determined by its tendency to accept electrons (a process known as **reduction**). A list or metals and halogens in order of their reactivity (highest to lowest) is called a **reactivity series** (or *activity series*). Only metals of higher reactivity can replace metals with lower reactivity. Likewise, only halogens of higher reactivity can replace halogens with lower reactivity. Below is a reactivity series for some common metals and halogens:\n",
    "\n",
    "Metals       | Cations           | Halogens | Anions\n",
    "---          | ---               | ---      | ---                                                          \n",
    "Potassium    | K<sup>+</sup>     | Fluorine | F<sup>-</sup>                                                                \n",
    "Sodium       | Na<sup>+</sup>    | Chlorine | Cl<sup>-</sup>\n",
    "Calcium      | Ca<sup>2+</sup>   | Bromine  | Br<sup>-</sup>\n",
    "Magnesium    | Mg<sup>2+</sup>   | Iodine   | I<sup>-</sup>\n",
    "Aluminum     | Al<sup>3+</sup>   | \n",
    "Manganese    | Mn<sup>2+</sup>   |  \n",
    "Zinc         | Zn<sup>2+</sup>   | \n",
    "Chromium     | Cr<sup>3+</sup>   | \n",
    "Iron         | Fe<sup>2+</sup>   | \n",
    "Cobalt       | Co<sup>2+</sup>   | \n",
    "Nickle       | Ni<sup>2+</sup>   | \n",
    "Tin          | Sn<sup>2+</sup>   | \n",
    "Lead         | Pb<sup>2+</sup>   | \n",
    "Hydrogen     | H<sup>+</sup>     | \n",
    "Copper       | Cu<sup>2+</sup>   | \n",
    "Mercury      | Hg<sup>2+</sup>   | \n",
    "Silver       | Ag<sup>+</sup>    | \n",
    "Gold         | Au<sup>3+</sup>   | \n",
    "Platinum     | Pt<sup>4+</sup>   | \n",
    "\n",
    "The reactivity series can be used to determine if a reaction will spontaneously occur. If the replacing element is more reactive (higher on the list) than the element it is replacing, then the reaction will spontaneously occur."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Using the reactivity series shown above, predict if each reaction will, or will not, spontaneously occur.* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 18,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "88f0ee4c377f453e8ec739cac80f8b9c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Will occur', style=ButtonStyle(button_color='Whitesmoke')), Button(descript…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "e7f085c56b2a409aa094387b9237618e",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Will occur', style=ButtonStyle(button_color='Whitesmoke')), Button(descript…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "7b7bd7e19c5b4934a0af9c9e74cfd5ac",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Will occur', style=ButtonStyle(button_color='Whitesmoke')), Button(descript…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "db673d14f2d6401dbe5e0a858d779588",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Will occur', style=ButtonStyle(button_color='Whitesmoke')), Button(descript…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "randomize_4 = random.randint(1, 2)\n",
    "if randomize_4 == 1:\n",
    "    option_1 = \"Al + H<sub>2</sub>O &rarr;\"; bool_1 = True\n",
    "elif randomize_4 == 2:\n",
    "    option_1 = \"Ag + H<sub>2</sub>O &rarr;\"; bool_1 = False\n",
    "\n",
    "randomize_4 = random.randint(1, 2)\n",
    "if randomize_4 == 1:\n",
    "    option_2 = \"AlPO<sub>4</sub> + Mg &rarr;\"; bool_2 = True\n",
    "elif randomize_4 == 2:\n",
    "    option_2 = \"AlPO<sub>4</sub> + Ni&rarr;\"; bool_2 = False\n",
    "\n",
    "randomize_4 = random.randint(1, 2)\n",
    "if randomize_4 == 1:\n",
    "    option_3 = \"F<sub>2</sub> + CaCl<sub>2</sub> &rarr;\"; bool_3 = True\n",
    "elif randomize_4 == 2:\n",
    "    option_3 = \"Br<sub>2</sub> + CaCl<sub>2</sub> &rarr;\"; bool_3 = False\n",
    "\n",
    "randomize_4 = random.randint(1, 2)\n",
    "if randomize_4 == 1:\n",
    "    option_4 = \"CuSO<sub>4</sub> + Zn &rarr;\"; bool_4 = True\n",
    "elif randomize_4 == 2:\n",
    "    option_4 = \"CuSO<sub>4</sub> + Hg &rarr;\"; bool_4 = False\n",
    "   \n",
    "true_false(option_1, bool_1, option_2, bool_2, option_3, bool_3, option_4, bool_4, \"Will occur\", \"Will not occur\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## <a id=\"double\"> #4 Double Replacement Reaction </a>\n",
    "\n",
    "A **double replacement reaction** (also called a *double displacement reaction*) describes the process in which the positive and negative ions from two compounds replace one another. The general form for a double replacement reaction is given below:\n",
    "\n",
    "<img src=\"images/double_displacement_reaction.svg\" width=\"92%\"/>\n",
    "\n",
    "The reactant side always contains two compounds. Likewise, the product side always contains two compounds. Only positive ions (cations) can exchange places with other positive ions. Likewise, only negative ions (anions) can exchange places with other negative ions.\n",
    "\n",
    "An example of a double replacement reaction is:\n",
    "\n",
    "<span style=\"color:red\">NaCl</span> + <span style=\"color:blue\">AgNO<sub>3</sub></span> &rarr; <span style=\"color:blue\">Ag</span><span style=\"color:red\">Cl</span> + <span style=\"color:red\">Na</span><span style=\"color:blue\">NO<sub>3</sub></span>"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Practice Problems"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Select 'True' or 'False' for each of the follow statements.* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 19,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "7ec14a2ed95d48528b477e416b183659",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "336c7c86a0974cc8a520b98ea56a1098",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "8e6be489c1904848bc1798883393ecce",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "199b22acdbf64db98d94d52ff69c7512",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='True', style=ButtonStyle(button_color='Whitesmoke')), Button(description='F…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "randomize_5 = random.randint(1, 2)\n",
    "if randomize_5 == 1:\n",
    "    option_1 = \"Double replacement reactions are also called double displacement reactions.\"; bool_1 = True\n",
    "elif randomize_5 == 2:\n",
    "    option_1 = \"Double replacement reactions are also called analysis reactions.\"; bool_1 = False\n",
    "\n",
    "randomize_5 = random.randint(1, 4)\n",
    "if randomize_5 == 1:\n",
    "    option_2 = \"The reactants used in a double replacement reaction always include two compounds.\"; bool_2 = True\n",
    "elif randomize_5 == 2:\n",
    "    option_2 = \"The reactants used in a double replacement reaction always include two compounds.\"; bool_2 = True\n",
    "elif randomize_5 == 3:\n",
    "    option_2 = \"The reactants used in a double replacement reaction always include two elements.\"; bool_2 = False\n",
    "elif randomize_5 == 4:\n",
    "    option_2 = \"The reactants used in a double replacement reaction always include one element and one compound.\"; bool_2 = False\n",
    "    \n",
    "randomize_5 = random.randint(1, 6)\n",
    "if randomize_5 == 1:\n",
    "    option_3 = \"The general form of a double replacement reaction is: AB + XY &rarr; XB + AY.\"; bool_3 = True\n",
    "elif randomize_5 == 2:\n",
    "    option_3 = \"The general form of a double replacement reaction is: AB + XY &rarr; XB + AY.\"; bool_3 = True\n",
    "elif randomize_5 == 3:\n",
    "    option_3 = \"The general form of a double replacement reaction is: AB + XY &rarr; AY + XB.\"; bool_3 = True\n",
    "elif randomize_5 == 4:\n",
    "    option_3 = \"The general form of a double replacement reaction is: A + B &rarr; AB.\"; bool_3 = False\n",
    "elif randomize_5 == 5:\n",
    "    option_3 = \"The general form of a double replacement reaction is: AB &rarr; A + B.\"; bool_3 = False\n",
    "elif randomize_5 == 6:\n",
    "    option_3 = \"The general form of a double replacement reaction is: AB + X &rarr; XB + A.\"; bool_3 = False\n",
    "\n",
    "randomize_5 = random.randint(1, 4)\n",
    "if randomize_5 == 1:\n",
    "    option_4 = \"The products generated from a double replacement reaction always include two compounds.\"; bool_4 = True\n",
    "elif randomize_5 == 2:\n",
    "    option_4 = \"The products generated from a double replacement reaction always include two compounds.\"; bool_4 = True\n",
    "elif randomize_5 == 3:\n",
    "    option_4 = \"The products generated from a double replacement reaction always include two elements.\"; bool_4 = False    \n",
    "elif randomize_5 == 4:\n",
    "    option_4 = \"The products generated from a double replacement reaction always include one element and one compound.\"; bool_4 = False \n",
    "    \n",
    "true_false(option_1, bool_1, option_2, bool_2, option_3, bool_3, option_4, bool_4, \"True\", \"False\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Which of the follow chemical reactions is a double replacement reaction?* "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 20,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "ffba42e00fa54663aed7990ab4e6ac87",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> 2Ni<sub>2</sub>O<sub>3</sub> &rarr; 4Ni + 3O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "7d6549dafcc54fabb1304cfd9f61711d",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 3AgNO<sub>3</sub> + Ni &rarr; Ni(NO)<sub>3</sub> + 3Ag')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "99323181aa28481fa5f93b09d82888a2",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2NaOH + CaBr<sub>2</sub> &rarr; 2NaBr + Ca(OH)<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "4db3f10d03204e4aa78d18c540649204",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> 3Mg + N<sub>2</sub> &rarr; Mg<sub>3</sub>N<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "4e1b210779fc4366ae25db6d82bf19d1",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"2NaOH + CaBr<sub>2</sub> &rarr; 2NaBr + Ca(OH)<sub>2</sub>\" \n",
    "option_2 = \"3Mg + N<sub>2</sub> &rarr; Mg<sub>3</sub>N<sub>2</sub>\"\n",
    "option_3 = \"2Ni<sub>2</sub>O<sub>3</sub> &rarr; 4Ni + 3O<sub>2</sub>\"\n",
    "option_4 = \"3AgNO<sub>3</sub> + Ni &rarr; Ni(NO)<sub>3</sub> + 3Ag\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 21,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "30c2747dff574e6c8812641fda98b577",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> Li<sub>2</sub>SO<sub>4</sub> + BaCl<sub>2</sub> &rarr; 2LiCl + BaSO<sub>4</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "d58385399c73435ca83e2a6cc0a20c64",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2AlBr<sub>3</sub> + 3Cl<sub>2</sub> &rarr; 2AlCl<sub>3</sub> + 3Br<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "6bd169b30a624941a6a0b2ac460a8adf",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> Al<sub>2</sub>O<sub>3</sub> &rarr; Al + O<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "e8c33ec06b7c4042aefea63bb3133912",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> 4Li + O<sub>2</sub> &rarr; 2Li<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "702e1d863d9c47f79e9ac1bda97b6284",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Li<sub>2</sub>SO<sub>4</sub> + BaCl<sub>2</sub> &rarr; 2LiCl + BaSO<sub>4</sub>\" \n",
    "option_2 = \"4Li + O<sub>2</sub> &rarr; 2Li<sub>2</sub>O\"\n",
    "option_3 = \"Al<sub>2</sub>O<sub>3</sub> &rarr; Al + O<sub>2</sub>\"\n",
    "option_4 = \"2AlBr<sub>3</sub> + 3Cl<sub>2</sub> &rarr; 2AlCl<sub>3</sub> + 3Br<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 22,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "4667922245044d08bba1389bf9b8c8a6",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> CaCO<sub>3</sub> &rarr; CaO + CO<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a0568f3302fb4fdbb5eac8363179fcae",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> 2Na + 2H<sub>2</sub>O &rarr; 2NaOH + H<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "05315369f4b74bbcb756a11373de3432",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> 2Cr + 3O<sub>2</sub> &rarr; 2CrO<sub>3</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "39f44568890f4bdf96df39d61d00d23c",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> Na<sub>2</sub>S + 2HCl &rarr; 2NaCl + H<sub>2</sub>S')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "9846cfcecd5e44c598b76286a5b0405e",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"Na<sub>2</sub>S + 2HCl &rarr; 2NaCl + H<sub>2</sub>S\" \n",
    "option_2 = \"2Cr + 3O<sub>2</sub> &rarr; 2CrO<sub>3</sub>\"\n",
    "option_3 = \"CaCO<sub>3</sub> &rarr; CaO + CO<sub>2</sub>\"\n",
    "option_4 = \"2Na + 2H<sub>2</sub>O &rarr; 2NaOH + H<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 23,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "05b02b77cb68488eaabbf1463a6f73ea",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(A)</b> 2NaI + Br<sub>2</sub> &rarr; 2NaBr + I<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "f2e5ec8551394872ad0fe1ac122bf0fe",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(B)</b> MgO + H<sub>2</sub>O &rarr; Mg(OH)<sub>2</sub>')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "e264243b0e744d30a112d2a39756bd66",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(C)</b> H<sub>2</sub>CO<sub>3</sub> &rarr; CO<sub>2</sub> + H<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "3421b25d6ed2464b8a60ecc1f053e305",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HTMLMath(value='<b>(D)</b> HCl + NaOH &rarr; NaCl + H<sub>2</sub>O')"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "03d79dbed4bb4a9694d5e24b876665ac",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='(A)', style=ButtonStyle(button_color='Whitesmoke')), Button(description='(B…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "#import ipywidgets as widgets\n",
    "#import random\n",
    "#from IPython.display import clear_output, display, HTML\n",
    "\n",
    "option_1 = \"HCl + NaOH &rarr; NaCl + H<sub>2</sub>O\" \n",
    "option_2 = \"MgO + H<sub>2</sub>O &rarr; Mg(OH)<sub>2</sub>\"\n",
    "option_3 = \"H<sub>2</sub>CO<sub>3</sub> &rarr; CO<sub>2</sub> + H<sub>2</sub>O\"\n",
    "option_4 = \"2NaI + Br<sub>2</sub> &rarr; 2NaBr + I<sub>2</sub>\"\n",
    "\n",
    "multiple_choice(option_1, option_2, option_3, option_4)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### Solubility Chart\n",
    "\n",
    "Often, double replacement reactions result in the precipitation of one product. **Precipitation** occurs when a substance is deposited in the form of a solid from a solution. A solubility chart can be used to determine whether or not a product will precipitate or remain in solution. An example of a solubility chart is shown below:\n",
    "\n",
    "Anions                                    | Cations that form soluble compounds | Cations that form insoluble compounds\n",
    "---                                       | ---                                 | ---                                                             \n",
    "Nitrate (NO<sub>3</sub><sup>-</sup>)      | All                                 | None\n",
    "Acetate (CH<sub>3</sub>COO<sup>-</sup>)   | All                                 | None\n",
    "Chlorate (ClO<sub>3</sub><sup>-</sup>)    | All                                 | None\n",
    "Perchlorate (ClO<sub>4</sub><sup>-</sup>) | All                                 | None\n",
    "----------------------------------- | ----------------------------------- | -----------------------------------\n",
    "Chloride (Cl<sup>-</sup>)                 | Most                                | Ag, Hg(I), Pb(II)\n",
    "Bromide (Br<sup>-</sup>)                  | Most                                | Ag, Hg(I), Pb(II)\n",
    "Iodide (I<sup>-</sup>)                    | Most                                | Ag, Hg(I), Pb(II)\n",
    "----------------------------------- | ----------------------------------- | -----------------------------------\n",
    "Fluoride (F<sup>-</sup>)                  | Most                                | Mg, Ca, Sr, Ba, Pb(II)\n",
    "----------------------------------- | ----------------------------------- | -----------------------------------\n",
    "Sulfate (SO<sub>4</sub><sup>2-</sup>)     | Most                                | Ba, Pb(II), Sr\n",
    "----------------------------------- | ----------------------------------- | -----------------------------------\n",
    "Carbonate (CO<sub>3</sub><sup>2-</sup>)   | (Group 1 Metals), NH<sub>4</sub>      | Most\n",
    "Sulfite (SO<sub>3</sub><sup>2-</sup>)     | (Group 1 Metals), NH<sub>4</sub>      | Most\n",
    "Phosphate (PO<sub>4</sub><sup>3-</sup>)   | (Group 1 Metals), NH<sub>4</sub>      | Most\n",
    "Chromate (CrO<sub>4</sub><sup>2-</sup>)   | (Group 1 Metals), NH<sub>4</sub>      | Most\n",
    "----------------------------------- | ----------------------------------- | -----------------------------------\n",
    "Sulfide (S<sup>2-</sup>)                  | (Group 1 Metals), NH<sub>4</sub>, Ca, Ba, Sr | Most\n",
    "Hydroxide (OH<sup>-</sup>)                | (Group 1 Metals), NH<sub>4</sub>, Ca, Ba, Sr | Most\n",
    "\n",
    "To use the solubility chart, match the anion and cation in the compound using the rows and columns on the chart. If the resulting compound is located in the second column, then the compound is soluble. If the compound is located in the third column, then the compound is insoluble.\n",
    "\n",
    "For example, consider the following reaction:\n",
    "\n",
    "AgNO<sub>3</sub> + KCl &rarr; AgCl + KNO<sub>3</sub>\n",
    "\n",
    "There are two products, AgCl and KNO<sub>3</sub>, formed in this reaction. For AgCl, the anion is chloride (Cl<sup>-</sup>) and the cation is silver (Ag<sup>+</sup>). Matching the anion and cation on the solubility table above (row 5, column 3) indicates that the compound is insoluble. In other words, the compound will form a precipitate. \n",
    "\n",
    "For KNO<sub>3</sub>, the anion is nitrate (NO<sub>3</sub><sup>-</sup>) and the cation is potassium (K<sup>+</sup>). Matching the anion and cation on the solubility table above (row 1, column 2) indicates that the compound is soluble. In other words, the compound will remain in solution."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "**Question:** *Using the solubility chart shown above, predict if each compound highlighted in <span style='color:red'>red</span> will dissolve or form a precipitate.*"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 24,
   "metadata": {
    "tags": [
     "hide-input"
    ]
   },
   "outputs": [
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "357f378307e64dd79b642b46045d6e6a",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Soluble', style=ButtonStyle(button_color='Whitesmoke')), Button(description…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "64cf7afda7e1433abd9d8f803cf955f7",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Soluble', style=ButtonStyle(button_color='Whitesmoke')), Button(description…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "a048128550244dc69e98994cac2a8f11",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Soluble', style=ButtonStyle(button_color='Whitesmoke')), Button(description…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "83ba40c9b5734ae1acbbc93eba0e83f2",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "HBox(children=(Button(description='Soluble', style=ButtonStyle(button_color='Whitesmoke')), Button(description…"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      " \r"
     ]
    }
   ],
   "source": [
    "randomize_6 = random.randint(1, 2)\n",
    "if randomize_6 == 1:\n",
    "    option_1 = \"Pb(NO<sub>3</sub>)<sub>2</sub> + 2AgCl &rarr; PbCl<sub>2</sub> + <span style='color:red'>2AgNO<sub>3</sub></span>\"; bool_1 = True\n",
    "elif randomize_6 == 2:\n",
    "    option_1 = \"Pb(NO<sub>3</sub>)<sub>2</sub> + 2AgCl &rarr; <span style='color:red'>PbCl<sub>2</sub></span> + 2AgNO<sub>3</sub>\"; bool_1 = False\n",
    "\n",
    "randomize_6 = random.randint(1, 2)\n",
    "if randomize_6 == 1:\n",
    "    option_2 = \"Mg(NO<sub>3</sub>)<sub>2</sub> + 2NaOH &rarr; Mg(OH)<sub>2</sub> + <span style='color:red'>2NaNO<sub>3</sub></span>\"; bool_2 = True\n",
    "elif randomize_6 == 2:\n",
    "    option_2 = \"Mg(NO<sub>3</sub>)<sub>2</sub> + 2NaOH &rarr; <span style='color:red'>Mg(OH)<sub>2</sub></span> + 2NaNO<sub>3</sub>\"; bool_2 = False\n",
    "\n",
    "randomize_6 = random.randint(1, 2)\n",
    "if randomize_6 == 1:\n",
    "    option_3 = \"ZnSO<sub>4</sub> + BaCl<sub>2</sub> &rarr; <span style='color:red'>ZnCl<sub>2</sub></span> + BaSO<sub>4</sub>\"; bool_3 = True\n",
    "elif randomize_6 == 2:\n",
    "    option_3 = \"ZnSO<sub>4</sub> + BaCl<sub>2</sub> &rarr; ZnCl<sub>2</sub> + <span style='color:red'>BaSO<sub>4</sub></sub>\"; bool_3 = False\n",
    "\n",
    "randomize_6 = random.randint(1, 2)\n",
    "if randomize_6 == 1:\n",
    "    option_4 = \"CaCl<sub>2</sub> + Na<sub>2</sub>CO<sub>3</sub> &rarr; CaCO<sub>3</sub> + <span style='color:red'>2NaCl</span>\"; bool_4 = True\n",
    "elif randomize_6 == 2:\n",
    "    option_4 = \"CaCl<sub>2</sub> + Na<sub>2</sub>CO<sub>3</sub> &rarr; <span style='color:red'>CaCO<sub>3</sub></span> + 2NaCl\"; bool_4 = False\n",
    "   \n",
    "true_false(option_1, bool_1, option_2, bool_2, option_3, bool_3, option_4, bool_4, \"Soluble\", \"Precipitate\")"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Conclusion"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "* A **chemical reaction** is a process that involves the rearrangement of the atoms in the molecular or ionic structure of a substance or material.\n",
    "* One common classification scheme organizes chemical reactions into four types: *combination, decomposition, single replacement, and double replacement reactions*.\n",
    "* The **general form** for each reaction type is given as follows:\n",
    "  + **Combination reaction:** A + B &rarr; AB\n",
    "  + **Decomposition reaction:** AB &rarr; A + B\n",
    "  + **Single replacement reaction:** AB + X &rarr; XB + A\n",
    "  + **Double replacement reaction:** AB + XY &rarr; XB + AY\n",
    "* The reactivity series can be used to determine if a reaction will spontaneously occur.\n",
    "* A solubility chart can be used to determine whether or not a product will form a precipitate or remain in solution.\n",
    "\n",
    "Images in this notebook represent original artwork."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "2+2"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "[![Callysto.ca License](https://github.com/callysto/curriculum-notebooks/blob/master/callysto-notebook-banner-bottom.jpg?raw=true)](https://github.com/callysto/curriculum-notebooks/blob/master/LICENSE.md)"
   ]
  }
 ],
 "metadata": {
  "celltoolbar": "Edit Metadata",
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.4"
  },
  "latex_envs": {
   "LaTeX_envs_menu_present": true,
   "autoclose": false,
   "autocomplete": true,
   "bibliofile": "biblio.bib",
   "cite_by": "apalike",
   "current_citInitial": 1,
   "eqLabelWithNumbers": true,
   "eqNumInitial": 1,
   "hotkeys": {
    "equation": "Ctrl-E",
    "itemize": "Ctrl-I"
   },
   "labels_anchors": false,
   "latex_user_defs": false,
   "report_style_numbering": false,
   "user_envs_cfg": false
  },
  "nbTranslate": {
   "displayLangs": [
    "*"
   ],
   "hotkey": "alt-t",
   "langInMainMenu": true,
   "sourceLang": "en",
   "targetLang": "fr",
   "useGoogleTranslate": true
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
